# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetTestGrokPatternResult',
    'AwaitableGetTestGrokPatternResult',
    'get_test_grok_pattern',
    'get_test_grok_pattern_output',
]

@pulumi.output_type
class GetTestGrokPatternResult:
    """
    A collection of values returned by getTestGrokPattern.
    """
    def __init__(__self__, account_id=None, grok=None, id=None, log_lines=None, test_groks=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if grok and not isinstance(grok, str):
            raise TypeError("Expected argument 'grok' to be a str")
        pulumi.set(__self__, "grok", grok)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if log_lines and not isinstance(log_lines, list):
            raise TypeError("Expected argument 'log_lines' to be a list")
        pulumi.set(__self__, "log_lines", log_lines)
        if test_groks and not isinstance(test_groks, list):
            raise TypeError("Expected argument 'test_groks' to be a list")
        pulumi.set(__self__, "test_groks", test_groks)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def grok(self) -> _builtins.str:
        return pulumi.get(self, "grok")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="logLines")
    def log_lines(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "log_lines")

    @_builtins.property
    @pulumi.getter(name="testGroks")
    def test_groks(self) -> Sequence['outputs.GetTestGrokPatternTestGrokResult']:
        """
        Nested attribute containing information about the test of Grok pattern against a list of log lines.
        """
        return pulumi.get(self, "test_groks")


class AwaitableGetTestGrokPatternResult(GetTestGrokPatternResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTestGrokPatternResult(
            account_id=self.account_id,
            grok=self.grok,
            id=self.id,
            log_lines=self.log_lines,
            test_groks=self.test_groks)


def get_test_grok_pattern(account_id: Optional[_builtins.str] = None,
                          grok: Optional[_builtins.str] = None,
                          log_lines: Optional[Sequence[_builtins.str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTestGrokPatternResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    # Data source
    foo = newrelic.get_test_grok_pattern(grok="%{IP:host_ip}",
        log_lines=[
            "host_ip: 43.3.120.2",
            "bytes_received: 2048",
        ])
    ```


    :param _builtins.str account_id: The New Relic account ID to operate on.  This allows you to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
    :param _builtins.str grok: The Grok pattern to test.
    :param Sequence[_builtins.str] log_lines: The log lines to test the Grok pattern against.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['grok'] = grok
    __args__['logLines'] = log_lines
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getTestGrokPattern:getTestGrokPattern', __args__, opts=opts, typ=GetTestGrokPatternResult).value

    return AwaitableGetTestGrokPatternResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        grok=pulumi.get(__ret__, 'grok'),
        id=pulumi.get(__ret__, 'id'),
        log_lines=pulumi.get(__ret__, 'log_lines'),
        test_groks=pulumi.get(__ret__, 'test_groks'))
def get_test_grok_pattern_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 grok: Optional[pulumi.Input[_builtins.str]] = None,
                                 log_lines: Optional[pulumi.Input[Sequence[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTestGrokPatternResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    # Data source
    foo = newrelic.get_test_grok_pattern(grok="%{IP:host_ip}",
        log_lines=[
            "host_ip: 43.3.120.2",
            "bytes_received: 2048",
        ])
    ```


    :param _builtins.str account_id: The New Relic account ID to operate on.  This allows you to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
    :param _builtins.str grok: The Grok pattern to test.
    :param Sequence[_builtins.str] log_lines: The log lines to test the Grok pattern against.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['grok'] = grok
    __args__['logLines'] = log_lines
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getTestGrokPattern:getTestGrokPattern', __args__, opts=opts, typ=GetTestGrokPatternResult)
    return __ret__.apply(lambda __response__: GetTestGrokPatternResult(
        account_id=pulumi.get(__response__, 'account_id'),
        grok=pulumi.get(__response__, 'grok'),
        id=pulumi.get(__response__, 'id'),
        log_lines=pulumi.get(__response__, 'log_lines'),
        test_groks=pulumi.get(__response__, 'test_groks')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NotificationDestinationArgs', 'NotificationDestination']

@pulumi.input_type
class NotificationDestinationArgs:
    def __init__(__self__, *,
                 properties: pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]],
                 type: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]] = None,
                 auth_token: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secure_url: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']] = None):
        """
        The set of arguments for constructing a NotificationDestination resource.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input[_builtins.str] type: (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input['NotificationDestinationAuthBasicArgs'] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input['NotificationDestinationAuthTokenArgs'] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input['NotificationDestinationSecureUrlArgs'] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        pulumi.set(__self__, "properties", properties)
        pulumi.set(__self__, "type", type)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if auth_basic is not None:
            pulumi.set(__self__, "auth_basic", auth_basic)
        if auth_custom_headers is not None:
            pulumi.set(__self__, "auth_custom_headers", auth_custom_headers)
        if auth_token is not None:
            pulumi.set(__self__, "auth_token", auth_token)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secure_url is not None:
            pulumi.set(__self__, "secure_url", secure_url)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]:
        """
        A nested block that describes a notification destination property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the destination is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="authBasic")
    def auth_basic(self) -> Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]:
        """
        A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        """
        return pulumi.get(self, "auth_basic")

    @auth_basic.setter
    def auth_basic(self, value: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]):
        pulumi.set(self, "auth_basic", value)

    @_builtins.property
    @pulumi.getter(name="authCustomHeaders")
    def auth_custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]:
        """
        A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        """
        return pulumi.get(self, "auth_custom_headers")

    @auth_custom_headers.setter
    def auth_custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]):
        pulumi.set(self, "auth_custom_headers", value)

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]:
        """
        A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        """
        return pulumi.get(self, "auth_token")

    @auth_token.setter
    def auth_token(self, value: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]):
        pulumi.set(self, "auth_token", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="secureUrl")
    def secure_url(self) -> Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]:
        """
        A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        return pulumi.get(self, "secure_url")

    @secure_url.setter
    def secure_url(self, value: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]):
        pulumi.set(self, "secure_url", value)


@pulumi.input_type
class _NotificationDestinationState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]] = None,
                 auth_token: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 last_sent: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]] = None,
                 secure_url: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering NotificationDestination resources.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input['NotificationDestinationAuthBasicArgs'] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input['NotificationDestinationAuthTokenArgs'] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] guid: The unique entity identifier of the destination in New Relic.
        :param pulumi.Input[_builtins.str] last_sent: The last time a notification was sent.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input['NotificationDestinationSecureUrlArgs'] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        :param pulumi.Input[_builtins.str] status: The status of the destination.
        :param pulumi.Input[_builtins.str] type: (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if active is not None:
            pulumi.set(__self__, "active", active)
        if auth_basic is not None:
            pulumi.set(__self__, "auth_basic", auth_basic)
        if auth_custom_headers is not None:
            pulumi.set(__self__, "auth_custom_headers", auth_custom_headers)
        if auth_token is not None:
            pulumi.set(__self__, "auth_token", auth_token)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if last_sent is not None:
            pulumi.set(__self__, "last_sent", last_sent)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if secure_url is not None:
            pulumi.set(__self__, "secure_url", secure_url)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the destination is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="authBasic")
    def auth_basic(self) -> Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]:
        """
        A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        """
        return pulumi.get(self, "auth_basic")

    @auth_basic.setter
    def auth_basic(self, value: Optional[pulumi.Input['NotificationDestinationAuthBasicArgs']]):
        pulumi.set(self, "auth_basic", value)

    @_builtins.property
    @pulumi.getter(name="authCustomHeaders")
    def auth_custom_headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]:
        """
        A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        """
        return pulumi.get(self, "auth_custom_headers")

    @auth_custom_headers.setter
    def auth_custom_headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationAuthCustomHeaderArgs']]]]):
        pulumi.set(self, "auth_custom_headers", value)

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]:
        """
        A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        """
        return pulumi.get(self, "auth_token")

    @auth_token.setter
    def auth_token(self, value: Optional[pulumi.Input['NotificationDestinationAuthTokenArgs']]):
        pulumi.set(self, "auth_token", value)

    @_builtins.property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique entity identifier of the destination in New Relic.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "guid", value)

    @_builtins.property
    @pulumi.getter(name="lastSent")
    def last_sent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last time a notification was sent.
        """
        return pulumi.get(self, "last_sent")

    @last_sent.setter
    def last_sent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_sent", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the destination.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]]:
        """
        A nested block that describes a notification destination property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NotificationDestinationPropertyArgs']]]]):
        pulumi.set(self, "properties", value)

    @_builtins.property
    @pulumi.getter(name="secureUrl")
    def secure_url(self) -> Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]:
        """
        A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        return pulumi.get(self, "secure_url")

    @secure_url.setter
    def secure_url(self, value: Optional[pulumi.Input['NotificationDestinationSecureUrlArgs']]):
        pulumi.set(self, "secure_url", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the destination.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("newrelic:index/notificationDestination:NotificationDestination")
class NotificationDestination(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']]] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]]] = None,
                 auth_token: Optional[pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]]] = None,
                 secure_url: Optional[pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        ~> **WARNING:** Slack-based destinations can only be imported and destroyed; this resource **does not** support creating and updating Slack-based destinations, owing to the reasons stated above, under the **Slack** section.

        Destination id can be found in the Destinations page -> three dots at the right of the chosen destination -> copy destination id to clipboard.

        This example is especially useful for slack destinations which *must* be imported.

        1. Add an empty resource to your terraform file:

        terraform

        resource "newrelic_notification_destination" "foo" {

        }

        ```sh
        $ pulumi import newrelic:index/notificationDestination:NotificationDestination  Run import command: `newrelic_notification_destination.foo <destination_id>`
        ```

        3. Run the following command after the import successfully done and copy the information to your resource:
           
           `terraform state show newrelic_notification_destination.foo`

        4. Add `ignore_changes` attribute on `all` in your imported resource:

        terraform

        lifecycle {

            ignore_changes = all

          }

        Your imported destination should look like that:

        terraform

        resource "newrelic_notification_destination" "foo" {

          lifecycle {

            ignore_changes = all

          }

          name = "*********"

          type = "SLACK"

          auth_token {

            prefix = "Bearer"

          }

          property {

              key   = "teamName"
            
              label = "Team Name"
            
              value = "******"

          }

        }

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        :param pulumi.Input[_builtins.str] type: (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NotificationDestinationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        ~> **WARNING:** Slack-based destinations can only be imported and destroyed; this resource **does not** support creating and updating Slack-based destinations, owing to the reasons stated above, under the **Slack** section.

        Destination id can be found in the Destinations page -> three dots at the right of the chosen destination -> copy destination id to clipboard.

        This example is especially useful for slack destinations which *must* be imported.

        1. Add an empty resource to your terraform file:

        terraform

        resource "newrelic_notification_destination" "foo" {

        }

        ```sh
        $ pulumi import newrelic:index/notificationDestination:NotificationDestination  Run import command: `newrelic_notification_destination.foo <destination_id>`
        ```

        3. Run the following command after the import successfully done and copy the information to your resource:
           
           `terraform state show newrelic_notification_destination.foo`

        4. Add `ignore_changes` attribute on `all` in your imported resource:

        terraform

        lifecycle {

            ignore_changes = all

          }

        Your imported destination should look like that:

        terraform

        resource "newrelic_notification_destination" "foo" {

          lifecycle {

            ignore_changes = all

          }

          name = "*********"

          type = "SLACK"

          auth_token {

            prefix = "Bearer"

          }

          property {

              key   = "teamName"
            
              label = "Team Name"
            
              value = "******"

          }

        }

        :param str resource_name: The name of the resource.
        :param NotificationDestinationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NotificationDestinationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 auth_basic: Optional[pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']]] = None,
                 auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]]] = None,
                 auth_token: Optional[pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]]] = None,
                 secure_url: Optional[pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NotificationDestinationArgs.__new__(NotificationDestinationArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["active"] = active
            __props__.__dict__["auth_basic"] = auth_basic
            __props__.__dict__["auth_custom_headers"] = auth_custom_headers
            __props__.__dict__["auth_token"] = auth_token
            __props__.__dict__["name"] = name
            if properties is None and not opts.urn:
                raise TypeError("Missing required property 'properties'")
            __props__.__dict__["properties"] = properties
            __props__.__dict__["secure_url"] = secure_url
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["guid"] = None
            __props__.__dict__["last_sent"] = None
            __props__.__dict__["status"] = None
        super(NotificationDestination, __self__).__init__(
            'newrelic:index/notificationDestination:NotificationDestination',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            auth_basic: Optional[pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']]] = None,
            auth_custom_headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]]] = None,
            auth_token: Optional[pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']]] = None,
            guid: Optional[pulumi.Input[_builtins.str]] = None,
            last_sent: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            properties: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]]] = None,
            secure_url: Optional[pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'NotificationDestination':
        """
        Get an existing NotificationDestination resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[_builtins.bool] active: Indicates whether the destination is active.
        :param pulumi.Input[Union['NotificationDestinationAuthBasicArgs', 'NotificationDestinationAuthBasicArgsDict']] auth_basic: A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationAuthCustomHeaderArgs', 'NotificationDestinationAuthCustomHeaderArgsDict']]]] auth_custom_headers: A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationAuthTokenArgs', 'NotificationDestinationAuthTokenArgsDict']] auth_token: A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        :param pulumi.Input[_builtins.str] guid: The unique entity identifier of the destination in New Relic.
        :param pulumi.Input[_builtins.str] last_sent: The last time a notification was sent.
        :param pulumi.Input[_builtins.str] name: The name of the destination.
        :param pulumi.Input[Sequence[pulumi.Input[Union['NotificationDestinationPropertyArgs', 'NotificationDestinationPropertyArgsDict']]]] properties: A nested block that describes a notification destination property. See Nested property blocks below for details.
        :param pulumi.Input[Union['NotificationDestinationSecureUrlArgs', 'NotificationDestinationSecureUrlArgsDict']] secure_url: A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        :param pulumi.Input[_builtins.str] status: The status of the destination.
        :param pulumi.Input[_builtins.str] type: (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NotificationDestinationState.__new__(_NotificationDestinationState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["active"] = active
        __props__.__dict__["auth_basic"] = auth_basic
        __props__.__dict__["auth_custom_headers"] = auth_custom_headers
        __props__.__dict__["auth_token"] = auth_token
        __props__.__dict__["guid"] = guid
        __props__.__dict__["last_sent"] = last_sent
        __props__.__dict__["name"] = name
        __props__.__dict__["properties"] = properties
        __props__.__dict__["secure_url"] = secure_url
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return NotificationDestination(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Determines the New Relic account where the notification destination will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whether the destination is active.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter(name="authBasic")
    def auth_basic(self) -> pulumi.Output[Optional['outputs.NotificationDestinationAuthBasic']]:
        """
        A nested block that describes a basic username and password authentication credentials. Only one auth_basic block is permitted per notification destination definition.  See Nested auth_basic blocks below for details.
        """
        return pulumi.get(self, "auth_basic")

    @_builtins.property
    @pulumi.getter(name="authCustomHeaders")
    def auth_custom_headers(self) -> pulumi.Output[Optional[Sequence['outputs.NotificationDestinationAuthCustomHeader']]]:
        """
        A nested block that describes a custom header authentication credentials. This field is required when the destination type is WORKFLOW_AUTOMATION and optional for other destination types. Multiple blocks are permitted per notification destination definition. Nested auth_custom_header blocks below for details.
        """
        return pulumi.get(self, "auth_custom_headers")

    @_builtins.property
    @pulumi.getter(name="authToken")
    def auth_token(self) -> pulumi.Output[Optional['outputs.NotificationDestinationAuthToken']]:
        """
        A nested block that describes a token authentication credentials. Only one auth_token block is permitted per notification destination definition.  See Nested auth_token blocks below for details.
        """
        return pulumi.get(self, "auth_token")

    @_builtins.property
    @pulumi.getter
    def guid(self) -> pulumi.Output[_builtins.str]:
        """
        The unique entity identifier of the destination in New Relic.
        """
        return pulumi.get(self, "guid")

    @_builtins.property
    @pulumi.getter(name="lastSent")
    def last_sent(self) -> pulumi.Output[_builtins.str]:
        """
        The last time a notification was sent.
        """
        return pulumi.get(self, "last_sent")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the destination.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Sequence['outputs.NotificationDestinationProperty']]:
        """
        A nested block that describes a notification destination property. See Nested property blocks below for details.
        """
        return pulumi.get(self, "properties")

    @_builtins.property
    @pulumi.getter(name="secureUrl")
    def secure_url(self) -> pulumi.Output[Optional['outputs.NotificationDestinationSecureUrl']]:
        """
        A nested block that describes a URL that contains sensitive data at the path or parameters. Only one secure_url block is permitted per notification destination definition. See Nested secure_url blocks below for details.
        """
        return pulumi.get(self, "secure_url")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the destination.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        (Required) The type of the destination. One of: (WEBHOOK, EMAIL, SERVICE_NOW, SERVICE_NOW_APP, PAGERDUTY_ACCOUNT_INTEGRATION, PAGERDUTY_SERVICE_INTEGRATION, JIRA, SLACK, SLACK_COLLABORATION, SLACK_LEGACY, MOBILE_PUSH, EVENT_BRIDGE, MICROSOFT_TEAMS, WORKFLOW_AUTOMATION).
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EventArgs', 'Event']

@pulumi.input_type
class EventArgs:
    def __init__(__self__, *,
                 events: pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]]):
        """
        The set of arguments for constructing a Event resource.
        :param pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]] events: An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        pulumi.set(__self__, "events", events)

    @_builtins.property
    @pulumi.getter
    def events(self) -> pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]]:
        """
        An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        return pulumi.get(self, "events")

    @events.setter
    def events(self, value: pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]]):
        pulumi.set(self, "events", value)


@pulumi.input_type
class _EventState:
    def __init__(__self__, *,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]]] = None):
        """
        Input properties used for looking up and filtering Event resources.
        :param pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]] events: An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        if events is not None:
            pulumi.set(__self__, "events", events)

    @_builtins.property
    @pulumi.getter
    def events(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]]]:
        """
        An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        return pulumi.get(self, "events")

    @events.setter
    def events(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EventEventArgs']]]]):
        pulumi.set(self, "events", value)


@pulumi.type_token("newrelic:insights/event:Event")
class Event(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EventEventArgs', 'EventEventArgsDict']]]]] = None,
                 __props__=None):
        """
        Use this resource to create one or more Insights events.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.insights.Event("foo", events=[{
            "type": "MyEvent",
            "timestamp": 1232471100,
            "attributes": [
                {
                    "key": "a_string_attribute",
                    "value": "a string",
                },
                {
                    "key": "an_integer_attribute",
                    "value": "42",
                    "type": "int",
                },
                {
                    "key": "a_float_attribute",
                    "value": "101.1",
                    "type": "float",
                },
            ],
        }])
        ```

        ## Events

        The `event` mapping supports the following arguments:

          * `type` - (Required) The event's name. Can be a combination of alphanumeric characters, underscores, and colons.
          * `timestamp` - (Optional) Must be a Unix epoch timestamp. You can define timestamps either in seconds or in milliseconds.
          * `attribute` - (Required) An attribute to include in your event payload. Multiple attribute blocks can be defined for an event. See Attributes below for details.

        ### Attributes

        The `attribute` mapping supports the following arguments:

          * `key` - (Required) The name of the attribute.
          * `value` - (Required) The value of the attribute.
          * `type` - (Optional) Specify the type for the attribute value. This is useful when passing integer or float values to Insights. Allowed values are `string`, `int`, or `float`. Defaults to `string`.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EventEventArgs', 'EventEventArgsDict']]]] events: An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EventArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create one or more Insights events.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.insights.Event("foo", events=[{
            "type": "MyEvent",
            "timestamp": 1232471100,
            "attributes": [
                {
                    "key": "a_string_attribute",
                    "value": "a string",
                },
                {
                    "key": "an_integer_attribute",
                    "value": "42",
                    "type": "int",
                },
                {
                    "key": "a_float_attribute",
                    "value": "101.1",
                    "type": "float",
                },
            ],
        }])
        ```

        ## Events

        The `event` mapping supports the following arguments:

          * `type` - (Required) The event's name. Can be a combination of alphanumeric characters, underscores, and colons.
          * `timestamp` - (Optional) Must be a Unix epoch timestamp. You can define timestamps either in seconds or in milliseconds.
          * `attribute` - (Required) An attribute to include in your event payload. Multiple attribute blocks can be defined for an event. See Attributes below for details.

        ### Attributes

        The `attribute` mapping supports the following arguments:

          * `key` - (Required) The name of the attribute.
          * `value` - (Required) The value of the attribute.
          * `type` - (Optional) Specify the type for the attribute value. This is useful when passing integer or float values to Insights. Allowed values are `string`, `int`, or `float`. Defaults to `string`.

        :param str resource_name: The name of the resource.
        :param EventArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EventArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 events: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EventEventArgs', 'EventEventArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EventArgs.__new__(EventArgs)

            if events is None and not opts.urn:
                raise TypeError("Missing required property 'events'")
            __props__.__dict__["events"] = events
        super(Event, __self__).__init__(
            'newrelic:insights/event:Event',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            events: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EventEventArgs', 'EventEventArgsDict']]]]] = None) -> 'Event':
        """
        Get an existing Event resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EventEventArgs', 'EventEventArgsDict']]]] events: An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EventState.__new__(_EventState)

        __props__.__dict__["events"] = events
        return Event(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def events(self) -> pulumi.Output[Sequence['outputs.EventEvent']]:
        """
        An event to insert into Insights. Multiple event blocks can be defined. See Events below for details.
        """
        return pulumi.get(self, "events")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['KeyTransactionArgs', 'KeyTransaction']

@pulumi.input_type
class KeyTransactionArgs:
    def __init__(__self__, *,
                 apdex_index: pulumi.Input[_builtins.float],
                 application_guid: pulumi.Input[_builtins.str],
                 browser_apdex_target: pulumi.Input[_builtins.float],
                 metric_name: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a KeyTransaction resource.
        :param pulumi.Input[_builtins.float] apdex_index: A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        :param pulumi.Input[_builtins.str] application_guid: The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        :param pulumi.Input[_builtins.float] browser_apdex_target: A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).
               
               > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        :param pulumi.Input[_builtins.str] metric_name: The name of the underlying metric monitored by the key transaction to be created.
        :param pulumi.Input[_builtins.str] name: The name of the key transaction.
        """
        pulumi.set(__self__, "apdex_index", apdex_index)
        pulumi.set(__self__, "application_guid", application_guid)
        pulumi.set(__self__, "browser_apdex_target", browser_apdex_target)
        pulumi.set(__self__, "metric_name", metric_name)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="apdexIndex")
    def apdex_index(self) -> pulumi.Input[_builtins.float]:
        """
        A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        """
        return pulumi.get(self, "apdex_index")

    @apdex_index.setter
    def apdex_index(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "apdex_index", value)

    @_builtins.property
    @pulumi.getter(name="applicationGuid")
    def application_guid(self) -> pulumi.Input[_builtins.str]:
        """
        The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        """
        return pulumi.get(self, "application_guid")

    @application_guid.setter
    def application_guid(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "application_guid", value)

    @_builtins.property
    @pulumi.getter(name="browserApdexTarget")
    def browser_apdex_target(self) -> pulumi.Input[_builtins.float]:
        """
        A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).

        > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        """
        return pulumi.get(self, "browser_apdex_target")

    @browser_apdex_target.setter
    def browser_apdex_target(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "browser_apdex_target", value)

    @_builtins.property
    @pulumi.getter(name="metricName")
    def metric_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the underlying metric monitored by the key transaction to be created.
        """
        return pulumi.get(self, "metric_name")

    @metric_name.setter
    def metric_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "metric_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the key transaction.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _KeyTransactionState:
    def __init__(__self__, *,
                 apdex_index: Optional[pulumi.Input[_builtins.float]] = None,
                 application_guid: Optional[pulumi.Input[_builtins.str]] = None,
                 browser_apdex_target: Optional[pulumi.Input[_builtins.float]] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 metric_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering KeyTransaction resources.
        :param pulumi.Input[_builtins.float] apdex_index: A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        :param pulumi.Input[_builtins.str] application_guid: The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        :param pulumi.Input[_builtins.float] browser_apdex_target: A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).
               
               > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        :param pulumi.Input[_builtins.str] domain: The domain of the entity monitored by the key transaction.
        :param pulumi.Input[_builtins.str] metric_name: The name of the underlying metric monitored by the key transaction to be created.
        :param pulumi.Input[_builtins.str] name: The name of the key transaction.
        :param pulumi.Input[_builtins.str] type: The type of the entity monitored by the key transaction.
        """
        if apdex_index is not None:
            pulumi.set(__self__, "apdex_index", apdex_index)
        if application_guid is not None:
            pulumi.set(__self__, "application_guid", application_guid)
        if browser_apdex_target is not None:
            pulumi.set(__self__, "browser_apdex_target", browser_apdex_target)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if metric_name is not None:
            pulumi.set(__self__, "metric_name", metric_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="apdexIndex")
    def apdex_index(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        """
        return pulumi.get(self, "apdex_index")

    @apdex_index.setter
    def apdex_index(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "apdex_index", value)

    @_builtins.property
    @pulumi.getter(name="applicationGuid")
    def application_guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        """
        return pulumi.get(self, "application_guid")

    @application_guid.setter
    def application_guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_guid", value)

    @_builtins.property
    @pulumi.getter(name="browserApdexTarget")
    def browser_apdex_target(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).

        > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        """
        return pulumi.get(self, "browser_apdex_target")

    @browser_apdex_target.setter
    def browser_apdex_target(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "browser_apdex_target", value)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain of the entity monitored by the key transaction.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter(name="metricName")
    def metric_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the underlying metric monitored by the key transaction to be created.
        """
        return pulumi.get(self, "metric_name")

    @metric_name.setter
    def metric_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metric_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the key transaction.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the entity monitored by the key transaction.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("newrelic:index/keyTransaction:KeyTransaction")
class KeyTransaction(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apdex_index: Optional[pulumi.Input[_builtins.float]] = None,
                 application_guid: Optional[pulumi.Input[_builtins.str]] = None,
                 browser_apdex_target: Optional[pulumi.Input[_builtins.float]] = None,
                 metric_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create a new Key Transaction in New Relic.

        > **NOTE:** For more information on Key Transactions, head over to [this page](https://docs.newrelic.com/docs/apm/transactions/key-transactions/introduction-key-transactions/) in New Relic's docs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.KeyTransaction("foo",
            application_guid="MzgfNjUyNnxBUE19QVBQTElDQVHJT068NTUfNDT4MjUy",
            apdex_index=0.5,
            browser_apdex_target=0.5,
            metric_name="WebTransaction/Function/__main__:foo_bar",
            name="Sample Key Transaction")
        ```

        ## Import

        A Key Transaction in New Relic may be imported into Terraform using its GUID specified in the `<id>` field, in the following command.

        bash

        ```sh
        $ pulumi import newrelic:index/keyTransaction:KeyTransaction foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.float] apdex_index: A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        :param pulumi.Input[_builtins.str] application_guid: The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        :param pulumi.Input[_builtins.float] browser_apdex_target: A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).
               
               > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        :param pulumi.Input[_builtins.str] metric_name: The name of the underlying metric monitored by the key transaction to be created.
        :param pulumi.Input[_builtins.str] name: The name of the key transaction.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeyTransactionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create a new Key Transaction in New Relic.

        > **NOTE:** For more information on Key Transactions, head over to [this page](https://docs.newrelic.com/docs/apm/transactions/key-transactions/introduction-key-transactions/) in New Relic's docs.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.KeyTransaction("foo",
            application_guid="MzgfNjUyNnxBUE19QVBQTElDQVHJT068NTUfNDT4MjUy",
            apdex_index=0.5,
            browser_apdex_target=0.5,
            metric_name="WebTransaction/Function/__main__:foo_bar",
            name="Sample Key Transaction")
        ```

        ## Import

        A Key Transaction in New Relic may be imported into Terraform using its GUID specified in the `<id>` field, in the following command.

        bash

        ```sh
        $ pulumi import newrelic:index/keyTransaction:KeyTransaction foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param KeyTransactionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeyTransactionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apdex_index: Optional[pulumi.Input[_builtins.float]] = None,
                 application_guid: Optional[pulumi.Input[_builtins.str]] = None,
                 browser_apdex_target: Optional[pulumi.Input[_builtins.float]] = None,
                 metric_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeyTransactionArgs.__new__(KeyTransactionArgs)

            if apdex_index is None and not opts.urn:
                raise TypeError("Missing required property 'apdex_index'")
            __props__.__dict__["apdex_index"] = apdex_index
            if application_guid is None and not opts.urn:
                raise TypeError("Missing required property 'application_guid'")
            __props__.__dict__["application_guid"] = application_guid
            if browser_apdex_target is None and not opts.urn:
                raise TypeError("Missing required property 'browser_apdex_target'")
            __props__.__dict__["browser_apdex_target"] = browser_apdex_target
            if metric_name is None and not opts.urn:
                raise TypeError("Missing required property 'metric_name'")
            __props__.__dict__["metric_name"] = metric_name
            __props__.__dict__["name"] = name
            __props__.__dict__["domain"] = None
            __props__.__dict__["type"] = None
        super(KeyTransaction, __self__).__init__(
            'newrelic:index/keyTransaction:KeyTransaction',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            apdex_index: Optional[pulumi.Input[_builtins.float]] = None,
            application_guid: Optional[pulumi.Input[_builtins.str]] = None,
            browser_apdex_target: Optional[pulumi.Input[_builtins.float]] = None,
            domain: Optional[pulumi.Input[_builtins.str]] = None,
            metric_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'KeyTransaction':
        """
        Get an existing KeyTransaction resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.float] apdex_index: A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        :param pulumi.Input[_builtins.str] application_guid: The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        :param pulumi.Input[_builtins.float] browser_apdex_target: A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).
               
               > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        :param pulumi.Input[_builtins.str] domain: The domain of the entity monitored by the key transaction.
        :param pulumi.Input[_builtins.str] metric_name: The name of the underlying metric monitored by the key transaction to be created.
        :param pulumi.Input[_builtins.str] name: The name of the key transaction.
        :param pulumi.Input[_builtins.str] type: The type of the entity monitored by the key transaction.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeyTransactionState.__new__(_KeyTransactionState)

        __props__.__dict__["apdex_index"] = apdex_index
        __props__.__dict__["application_guid"] = application_guid
        __props__.__dict__["browser_apdex_target"] = browser_apdex_target
        __props__.__dict__["domain"] = domain
        __props__.__dict__["metric_name"] = metric_name
        __props__.__dict__["name"] = name
        __props__.__dict__["type"] = type
        return KeyTransaction(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="apdexIndex")
    def apdex_index(self) -> pulumi.Output[_builtins.float]:
        """
        A decimal value, measuring user satisfaction with response times, ranging from 0 (frustrated) to 1 (satisfied).
        """
        return pulumi.get(self, "apdex_index")

    @_builtins.property
    @pulumi.getter(name="applicationGuid")
    def application_guid(self) -> pulumi.Output[_builtins.str]:
        """
        The GUID of the APM Application comprising transactions, of which one would be made a key transaction.
        """
        return pulumi.get(self, "application_guid")

    @_builtins.property
    @pulumi.getter(name="browserApdexTarget")
    def browser_apdex_target(self) -> pulumi.Output[_builtins.float]:
        """
        A decimal value representing the response time threshold for satisfactory experience (e.g., 0.5 seconds).

        > **NOTE:** It may be noted that the `metric_name` and `application_guid` of a Key Transaction _cannot_ be updated in a key transaction that has already been created; since this is not supported. As a consequence, altering the values of `application_guid` and/or `metric_name` of a `KeyTransaction` resource created (to try updating these values) would result in `pulumi preview` prompting a forced destruction and re-creation of the resource.
        """
        return pulumi.get(self, "browser_apdex_target")

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Output[_builtins.str]:
        """
        The domain of the entity monitored by the key transaction.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter(name="metricName")
    def metric_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the underlying metric monitored by the key transaction to be created.
        """
        return pulumi.get(self, "metric_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the key transaction.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the entity monitored by the key transaction.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkflowArgs', 'Workflow']

@pulumi.input_type
class WorkflowArgs:
    def __init__(__self__, *,
                 destinations: pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]],
                 issues_filter: pulumi.Input['WorkflowIssuesFilterArgs'],
                 muting_rules_handling: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 destinations_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enrichments: Optional[pulumi.Input['WorkflowEnrichmentsArgs']] = None,
                 enrichments_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Workflow resource.
        :param pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]] destinations: Notification configuration. See Nested destination blocks below for details.
        :param pulumi.Input['WorkflowIssuesFilterArgs'] issues_filter: A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        :param pulumi.Input[_builtins.str] muting_rules_handling: How to handle muted issues. See Muting Rules below for details.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        :param pulumi.Input[_builtins.bool] destinations_enabled: **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
               these two are different flags, but they are functionally identical. Defaults to true.
        :param pulumi.Input[_builtins.bool] enabled: Whether workflow is enabled. Defaults to true.
        :param pulumi.Input['WorkflowEnrichmentsArgs'] enrichments: Workflow's enrichments. See Nested enrichments blocks below for details.
        :param pulumi.Input[_builtins.bool] enrichments_enabled: Whether enrichments are enabled. Defaults to true.
        :param pulumi.Input[_builtins.str] name: The name of the workflow.
        """
        pulumi.set(__self__, "destinations", destinations)
        pulumi.set(__self__, "issues_filter", issues_filter)
        pulumi.set(__self__, "muting_rules_handling", muting_rules_handling)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if destinations_enabled is not None:
            warnings.warn("""Please use 'enabled' instead""", DeprecationWarning)
            pulumi.log.warn("""destinations_enabled is deprecated: Please use 'enabled' instead""")
        if destinations_enabled is not None:
            pulumi.set(__self__, "destinations_enabled", destinations_enabled)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if enrichments is not None:
            pulumi.set(__self__, "enrichments", enrichments)
        if enrichments_enabled is not None:
            pulumi.set(__self__, "enrichments_enabled", enrichments_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def destinations(self) -> pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]]:
        """
        Notification configuration. See Nested destination blocks below for details.
        """
        return pulumi.get(self, "destinations")

    @destinations.setter
    def destinations(self, value: pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]]):
        pulumi.set(self, "destinations", value)

    @_builtins.property
    @pulumi.getter(name="issuesFilter")
    def issues_filter(self) -> pulumi.Input['WorkflowIssuesFilterArgs']:
        """
        A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        """
        return pulumi.get(self, "issues_filter")

    @issues_filter.setter
    def issues_filter(self, value: pulumi.Input['WorkflowIssuesFilterArgs']):
        pulumi.set(self, "issues_filter", value)

    @_builtins.property
    @pulumi.getter(name="mutingRulesHandling")
    def muting_rules_handling(self) -> pulumi.Input[_builtins.str]:
        """
        How to handle muted issues. See Muting Rules below for details.
        """
        return pulumi.get(self, "muting_rules_handling")

    @muting_rules_handling.setter
    def muting_rules_handling(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "muting_rules_handling", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="destinationsEnabled")
    @_utilities.deprecated("""Please use 'enabled' instead""")
    def destinations_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
        these two are different flags, but they are functionally identical. Defaults to true.
        """
        return pulumi.get(self, "destinations_enabled")

    @destinations_enabled.setter
    def destinations_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "destinations_enabled", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether workflow is enabled. Defaults to true.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def enrichments(self) -> Optional[pulumi.Input['WorkflowEnrichmentsArgs']]:
        """
        Workflow's enrichments. See Nested enrichments blocks below for details.
        """
        return pulumi.get(self, "enrichments")

    @enrichments.setter
    def enrichments(self, value: Optional[pulumi.Input['WorkflowEnrichmentsArgs']]):
        pulumi.set(self, "enrichments", value)

    @_builtins.property
    @pulumi.getter(name="enrichmentsEnabled")
    def enrichments_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether enrichments are enabled. Defaults to true.
        """
        return pulumi.get(self, "enrichments_enabled")

    @enrichments_enabled.setter
    def enrichments_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enrichments_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the workflow.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _WorkflowState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 destinations: Optional[pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]]] = None,
                 destinations_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enrichments: Optional[pulumi.Input['WorkflowEnrichmentsArgs']] = None,
                 enrichments_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 issues_filter: Optional[pulumi.Input['WorkflowIssuesFilterArgs']] = None,
                 last_run: Optional[pulumi.Input[_builtins.str]] = None,
                 muting_rules_handling: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 workflow_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Workflow resources.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        :param pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]] destinations: Notification configuration. See Nested destination blocks below for details.
        :param pulumi.Input[_builtins.bool] destinations_enabled: **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
               these two are different flags, but they are functionally identical. Defaults to true.
        :param pulumi.Input[_builtins.bool] enabled: Whether workflow is enabled. Defaults to true.
        :param pulumi.Input['WorkflowEnrichmentsArgs'] enrichments: Workflow's enrichments. See Nested enrichments blocks below for details.
        :param pulumi.Input[_builtins.bool] enrichments_enabled: Whether enrichments are enabled. Defaults to true.
        :param pulumi.Input[_builtins.str] guid: Workflow entity GUID
        :param pulumi.Input['WorkflowIssuesFilterArgs'] issues_filter: A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        :param pulumi.Input[_builtins.str] last_run: The last time notification was sent for this workflow.
        :param pulumi.Input[_builtins.str] muting_rules_handling: How to handle muted issues. See Muting Rules below for details.
        :param pulumi.Input[_builtins.str] name: The name of the workflow.
        :param pulumi.Input[_builtins.str] workflow_id: The id of the workflow.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if destinations is not None:
            pulumi.set(__self__, "destinations", destinations)
        if destinations_enabled is not None:
            warnings.warn("""Please use 'enabled' instead""", DeprecationWarning)
            pulumi.log.warn("""destinations_enabled is deprecated: Please use 'enabled' instead""")
        if destinations_enabled is not None:
            pulumi.set(__self__, "destinations_enabled", destinations_enabled)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if enrichments is not None:
            pulumi.set(__self__, "enrichments", enrichments)
        if enrichments_enabled is not None:
            pulumi.set(__self__, "enrichments_enabled", enrichments_enabled)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if issues_filter is not None:
            pulumi.set(__self__, "issues_filter", issues_filter)
        if last_run is not None:
            pulumi.set(__self__, "last_run", last_run)
        if muting_rules_handling is not None:
            pulumi.set(__self__, "muting_rules_handling", muting_rules_handling)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if workflow_id is not None:
            pulumi.set(__self__, "workflow_id", workflow_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def destinations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]]]:
        """
        Notification configuration. See Nested destination blocks below for details.
        """
        return pulumi.get(self, "destinations")

    @destinations.setter
    def destinations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkflowDestinationArgs']]]]):
        pulumi.set(self, "destinations", value)

    @_builtins.property
    @pulumi.getter(name="destinationsEnabled")
    @_utilities.deprecated("""Please use 'enabled' instead""")
    def destinations_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
        these two are different flags, but they are functionally identical. Defaults to true.
        """
        return pulumi.get(self, "destinations_enabled")

    @destinations_enabled.setter
    def destinations_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "destinations_enabled", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether workflow is enabled. Defaults to true.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def enrichments(self) -> Optional[pulumi.Input['WorkflowEnrichmentsArgs']]:
        """
        Workflow's enrichments. See Nested enrichments blocks below for details.
        """
        return pulumi.get(self, "enrichments")

    @enrichments.setter
    def enrichments(self, value: Optional[pulumi.Input['WorkflowEnrichmentsArgs']]):
        pulumi.set(self, "enrichments", value)

    @_builtins.property
    @pulumi.getter(name="enrichmentsEnabled")
    def enrichments_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether enrichments are enabled. Defaults to true.
        """
        return pulumi.get(self, "enrichments_enabled")

    @enrichments_enabled.setter
    def enrichments_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enrichments_enabled", value)

    @_builtins.property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Workflow entity GUID
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "guid", value)

    @_builtins.property
    @pulumi.getter(name="issuesFilter")
    def issues_filter(self) -> Optional[pulumi.Input['WorkflowIssuesFilterArgs']]:
        """
        A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        """
        return pulumi.get(self, "issues_filter")

    @issues_filter.setter
    def issues_filter(self, value: Optional[pulumi.Input['WorkflowIssuesFilterArgs']]):
        pulumi.set(self, "issues_filter", value)

    @_builtins.property
    @pulumi.getter(name="lastRun")
    def last_run(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The last time notification was sent for this workflow.
        """
        return pulumi.get(self, "last_run")

    @last_run.setter
    def last_run(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_run", value)

    @_builtins.property
    @pulumi.getter(name="mutingRulesHandling")
    def muting_rules_handling(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        How to handle muted issues. See Muting Rules below for details.
        """
        return pulumi.get(self, "muting_rules_handling")

    @muting_rules_handling.setter
    def muting_rules_handling(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "muting_rules_handling", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the workflow.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="workflowId")
    def workflow_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the workflow.
        """
        return pulumi.get(self, "workflow_id")

    @workflow_id.setter
    def workflow_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "workflow_id", value)


@pulumi.type_token("newrelic:index/workflow:Workflow")
class Workflow(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 destinations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkflowDestinationArgs', 'WorkflowDestinationArgsDict']]]]] = None,
                 destinations_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enrichments: Optional[pulumi.Input[Union['WorkflowEnrichmentsArgs', 'WorkflowEnrichmentsArgsDict']]] = None,
                 enrichments_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 issues_filter: Optional[pulumi.Input[Union['WorkflowIssuesFilterArgs', 'WorkflowIssuesFilterArgsDict']]] = None,
                 muting_rules_handling: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create and manage New Relic workflows.

        ## Example Usage

        ##### Workflow
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.Workflow("foo",
            name="workflow-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "accumulations.tag.team",
                    "operator": "EXACTLY_MATCHES",
                    "values": ["growth"],
                }],
            },
            destinations=[{
                "channel_id": some_channel["id"],
            }])
        ```

        ## Policy-Based Workflow Example

        This scenario describes one of most common ways of using workflows by defining a set of policies the workflow handles

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        # Create a policy to track
        my_policy = newrelic.AlertPolicy("my-policy", name="my_policy")
        # Create a reusable notification destination
        webhook_destination = newrelic.NotificationDestination("webhook-destination",
            name="destination-webhook",
            type="WEBHOOK",
            properties=[{
                "key": "url",
                "value": "https://example.com",
            }],
            auth_basic={
                "user": "username",
                "password": "password",
            })
        # Create a notification channel to use in the workflow
        webhook_channel = newrelic.NotificationChannel("webhook-channel",
            name="channel-webhook",
            type="WEBHOOK",
            destination_id=webhook_destination.id,
            product="IINT",
            properties=[{
                "key": "payload",
                "value": "{}",
                "label": "Payload Template",
            }])
        # A workflow that matches issues that include incidents triggered by the policy
        workflow_example = newrelic.Workflow("workflow-example",
            name="workflow-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "Filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "labels.policyIds",
                    "operator": "EXACTLY_MATCHES",
                    "values": [my_policy.id],
                }],
            },
            destinations=[{
                "channel_id": webhook_channel.id,
            }])
        ```

        ### An example of a workflow with enrichments

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        workflow_example = newrelic.Workflow("workflow-example",
            name="workflow-enrichment-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "Filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "accumulations.tag.team",
                    "operator": "EXACTLY_MATCHES",
                    "values": ["my_team"],
                }],
            },
            enrichments={
                "nrqls": [{
                    "name": "Log Count",
                    "configurations": [{
                        "query": "SELECT count(*) FROM Log WHERE message like '%error%' since 10 minutes ago",
                    }],
                }],
            },
            destinations=[{
                "channel_id": webhook_channel["id"],
            }])
        ```

        ### An example of a workflow with notification triggers

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        workflow_example = newrelic.Workflow("workflow-example",
            name="workflow-enrichment-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "Filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "accumulations.tag.team",
                    "operator": "EXACTLY_MATCHES",
                    "values": ["my_team"],
                }],
            },
            destinations=[{
                "channel_id": webhook_channel["id"],
                "notification_triggers": ["ACTIVATED"],
            }])
        ```

        ## Additional Information

        More details about the workflows can be found [here](https://docs.newrelic.com/docs/alerts-applied-intelligence/applied-intelligence/incident-workflows/incident-workflows/).

        ### Moving from Legacy Alert Policy Channels to Workflows
        As described in the documentation of this resource, mapping alert channels (created using `NotificationDestination` and `NotificationChannel`) to policies can be performed using the `Workflow` resource, which is an alternative to the legacy resource `AlertPolicyChannel` (which consumes alert channels created using the legacy resource `AlertChannel`).

        Both of the legacy resources mentioned above, `AlertChannel` and `AlertPolicyChannel` are **deprecated** and will be **removed in a future major release**, as stated in the documentation of both of these resources.

        If you're currently using `AlertChannel` and `AlertPolicyChannel` to manage alert channels linked to policies, we **strongly recommend** migrating to these workflows and notifications-based resources at the earliest.

        Please refer to the examples in this page, or this example for illustrations on setting up channels and workflows with these resources.

        ## v3.3 changes

        In version v3.3 we renamed the following arguments:

        - `workflow_enabled` changed to `enabled`.
        - `destination_configuration` changed to `destination`.
        - `predicates` changed to `predicate`.
        - Enrichment's `configurations` changed to `configuration`.

        ## Import

        Workflows can be imported using the `id`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/workflow:Workflow foo <id>
        ```

        You can find the workflow ID from the workflow table by clicking on ... at the end of the row and choosing `Copy workflow id to clipboard`.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkflowDestinationArgs', 'WorkflowDestinationArgsDict']]]] destinations: Notification configuration. See Nested destination blocks below for details.
        :param pulumi.Input[_builtins.bool] destinations_enabled: **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
               these two are different flags, but they are functionally identical. Defaults to true.
        :param pulumi.Input[_builtins.bool] enabled: Whether workflow is enabled. Defaults to true.
        :param pulumi.Input[Union['WorkflowEnrichmentsArgs', 'WorkflowEnrichmentsArgsDict']] enrichments: Workflow's enrichments. See Nested enrichments blocks below for details.
        :param pulumi.Input[_builtins.bool] enrichments_enabled: Whether enrichments are enabled. Defaults to true.
        :param pulumi.Input[Union['WorkflowIssuesFilterArgs', 'WorkflowIssuesFilterArgsDict']] issues_filter: A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        :param pulumi.Input[_builtins.str] muting_rules_handling: How to handle muted issues. See Muting Rules below for details.
        :param pulumi.Input[_builtins.str] name: The name of the workflow.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: WorkflowArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create and manage New Relic workflows.

        ## Example Usage

        ##### Workflow
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.Workflow("foo",
            name="workflow-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "accumulations.tag.team",
                    "operator": "EXACTLY_MATCHES",
                    "values": ["growth"],
                }],
            },
            destinations=[{
                "channel_id": some_channel["id"],
            }])
        ```

        ## Policy-Based Workflow Example

        This scenario describes one of most common ways of using workflows by defining a set of policies the workflow handles

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        # Create a policy to track
        my_policy = newrelic.AlertPolicy("my-policy", name="my_policy")
        # Create a reusable notification destination
        webhook_destination = newrelic.NotificationDestination("webhook-destination",
            name="destination-webhook",
            type="WEBHOOK",
            properties=[{
                "key": "url",
                "value": "https://example.com",
            }],
            auth_basic={
                "user": "username",
                "password": "password",
            })
        # Create a notification channel to use in the workflow
        webhook_channel = newrelic.NotificationChannel("webhook-channel",
            name="channel-webhook",
            type="WEBHOOK",
            destination_id=webhook_destination.id,
            product="IINT",
            properties=[{
                "key": "payload",
                "value": "{}",
                "label": "Payload Template",
            }])
        # A workflow that matches issues that include incidents triggered by the policy
        workflow_example = newrelic.Workflow("workflow-example",
            name="workflow-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "Filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "labels.policyIds",
                    "operator": "EXACTLY_MATCHES",
                    "values": [my_policy.id],
                }],
            },
            destinations=[{
                "channel_id": webhook_channel.id,
            }])
        ```

        ### An example of a workflow with enrichments

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        workflow_example = newrelic.Workflow("workflow-example",
            name="workflow-enrichment-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "Filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "accumulations.tag.team",
                    "operator": "EXACTLY_MATCHES",
                    "values": ["my_team"],
                }],
            },
            enrichments={
                "nrqls": [{
                    "name": "Log Count",
                    "configurations": [{
                        "query": "SELECT count(*) FROM Log WHERE message like '%error%' since 10 minutes ago",
                    }],
                }],
            },
            destinations=[{
                "channel_id": webhook_channel["id"],
            }])
        ```

        ### An example of a workflow with notification triggers

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        workflow_example = newrelic.Workflow("workflow-example",
            name="workflow-enrichment-example",
            muting_rules_handling="NOTIFY_ALL_ISSUES",
            issues_filter={
                "name": "Filter-name",
                "type": "FILTER",
                "predicates": [{
                    "attribute": "accumulations.tag.team",
                    "operator": "EXACTLY_MATCHES",
                    "values": ["my_team"],
                }],
            },
            destinations=[{
                "channel_id": webhook_channel["id"],
                "notification_triggers": ["ACTIVATED"],
            }])
        ```

        ## Additional Information

        More details about the workflows can be found [here](https://docs.newrelic.com/docs/alerts-applied-intelligence/applied-intelligence/incident-workflows/incident-workflows/).

        ### Moving from Legacy Alert Policy Channels to Workflows
        As described in the documentation of this resource, mapping alert channels (created using `NotificationDestination` and `NotificationChannel`) to policies can be performed using the `Workflow` resource, which is an alternative to the legacy resource `AlertPolicyChannel` (which consumes alert channels created using the legacy resource `AlertChannel`).

        Both of the legacy resources mentioned above, `AlertChannel` and `AlertPolicyChannel` are **deprecated** and will be **removed in a future major release**, as stated in the documentation of both of these resources.

        If you're currently using `AlertChannel` and `AlertPolicyChannel` to manage alert channels linked to policies, we **strongly recommend** migrating to these workflows and notifications-based resources at the earliest.

        Please refer to the examples in this page, or this example for illustrations on setting up channels and workflows with these resources.

        ## v3.3 changes

        In version v3.3 we renamed the following arguments:

        - `workflow_enabled` changed to `enabled`.
        - `destination_configuration` changed to `destination`.
        - `predicates` changed to `predicate`.
        - Enrichment's `configurations` changed to `configuration`.

        ## Import

        Workflows can be imported using the `id`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/workflow:Workflow foo <id>
        ```

        You can find the workflow ID from the workflow table by clicking on ... at the end of the row and choosing `Copy workflow id to clipboard`.

        :param str resource_name: The name of the resource.
        :param WorkflowArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkflowArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 destinations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkflowDestinationArgs', 'WorkflowDestinationArgsDict']]]]] = None,
                 destinations_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 enrichments: Optional[pulumi.Input[Union['WorkflowEnrichmentsArgs', 'WorkflowEnrichmentsArgsDict']]] = None,
                 enrichments_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 issues_filter: Optional[pulumi.Input[Union['WorkflowIssuesFilterArgs', 'WorkflowIssuesFilterArgsDict']]] = None,
                 muting_rules_handling: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkflowArgs.__new__(WorkflowArgs)

            __props__.__dict__["account_id"] = account_id
            if destinations is None and not opts.urn:
                raise TypeError("Missing required property 'destinations'")
            __props__.__dict__["destinations"] = destinations
            __props__.__dict__["destinations_enabled"] = destinations_enabled
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["enrichments"] = enrichments
            __props__.__dict__["enrichments_enabled"] = enrichments_enabled
            if issues_filter is None and not opts.urn:
                raise TypeError("Missing required property 'issues_filter'")
            __props__.__dict__["issues_filter"] = issues_filter
            if muting_rules_handling is None and not opts.urn:
                raise TypeError("Missing required property 'muting_rules_handling'")
            __props__.__dict__["muting_rules_handling"] = muting_rules_handling
            __props__.__dict__["name"] = name
            __props__.__dict__["guid"] = None
            __props__.__dict__["last_run"] = None
            __props__.__dict__["workflow_id"] = None
        super(Workflow, __self__).__init__(
            'newrelic:index/workflow:Workflow',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            destinations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkflowDestinationArgs', 'WorkflowDestinationArgsDict']]]]] = None,
            destinations_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            enrichments: Optional[pulumi.Input[Union['WorkflowEnrichmentsArgs', 'WorkflowEnrichmentsArgsDict']]] = None,
            enrichments_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            guid: Optional[pulumi.Input[_builtins.str]] = None,
            issues_filter: Optional[pulumi.Input[Union['WorkflowIssuesFilterArgs', 'WorkflowIssuesFilterArgsDict']]] = None,
            last_run: Optional[pulumi.Input[_builtins.str]] = None,
            muting_rules_handling: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            workflow_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Workflow':
        """
        Get an existing Workflow resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkflowDestinationArgs', 'WorkflowDestinationArgsDict']]]] destinations: Notification configuration. See Nested destination blocks below for details.
        :param pulumi.Input[_builtins.bool] destinations_enabled: **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
               these two are different flags, but they are functionally identical. Defaults to true.
        :param pulumi.Input[_builtins.bool] enabled: Whether workflow is enabled. Defaults to true.
        :param pulumi.Input[Union['WorkflowEnrichmentsArgs', 'WorkflowEnrichmentsArgsDict']] enrichments: Workflow's enrichments. See Nested enrichments blocks below for details.
        :param pulumi.Input[_builtins.bool] enrichments_enabled: Whether enrichments are enabled. Defaults to true.
        :param pulumi.Input[_builtins.str] guid: Workflow entity GUID
        :param pulumi.Input[Union['WorkflowIssuesFilterArgs', 'WorkflowIssuesFilterArgsDict']] issues_filter: A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        :param pulumi.Input[_builtins.str] last_run: The last time notification was sent for this workflow.
        :param pulumi.Input[_builtins.str] muting_rules_handling: How to handle muted issues. See Muting Rules below for details.
        :param pulumi.Input[_builtins.str] name: The name of the workflow.
        :param pulumi.Input[_builtins.str] workflow_id: The id of the workflow.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkflowState.__new__(_WorkflowState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["destinations"] = destinations
        __props__.__dict__["destinations_enabled"] = destinations_enabled
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["enrichments"] = enrichments
        __props__.__dict__["enrichments_enabled"] = enrichments_enabled
        __props__.__dict__["guid"] = guid
        __props__.__dict__["issues_filter"] = issues_filter
        __props__.__dict__["last_run"] = last_run
        __props__.__dict__["muting_rules_handling"] = muting_rules_handling
        __props__.__dict__["name"] = name
        __props__.__dict__["workflow_id"] = workflow_id
        return Workflow(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Determines the New Relic account in which the workflow is created. Defaults to the account defined in the provider section.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def destinations(self) -> pulumi.Output[Sequence['outputs.WorkflowDestination']]:
        """
        Notification configuration. See Nested destination blocks below for details.
        """
        return pulumi.get(self, "destinations")

    @_builtins.property
    @pulumi.getter(name="destinationsEnabled")
    @_utilities.deprecated("""Please use 'enabled' instead""")
    def destinations_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        **DEPRECATED** Whether destinations are enabled. Please use `enabled` instead:
        these two are different flags, but they are functionally identical. Defaults to true.
        """
        return pulumi.get(self, "destinations_enabled")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether workflow is enabled. Defaults to true.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def enrichments(self) -> pulumi.Output[Optional['outputs.WorkflowEnrichments']]:
        """
        Workflow's enrichments. See Nested enrichments blocks below for details.
        """
        return pulumi.get(self, "enrichments")

    @_builtins.property
    @pulumi.getter(name="enrichmentsEnabled")
    def enrichments_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether enrichments are enabled. Defaults to true.
        """
        return pulumi.get(self, "enrichments_enabled")

    @_builtins.property
    @pulumi.getter
    def guid(self) -> pulumi.Output[_builtins.str]:
        """
        Workflow entity GUID
        """
        return pulumi.get(self, "guid")

    @_builtins.property
    @pulumi.getter(name="issuesFilter")
    def issues_filter(self) -> pulumi.Output['outputs.WorkflowIssuesFilter']:
        """
        A filter used to identify issues handled by this workflow. See Nested issues_filter blocks below for details.
        """
        return pulumi.get(self, "issues_filter")

    @_builtins.property
    @pulumi.getter(name="lastRun")
    def last_run(self) -> pulumi.Output[_builtins.str]:
        """
        The last time notification was sent for this workflow.
        """
        return pulumi.get(self, "last_run")

    @_builtins.property
    @pulumi.getter(name="mutingRulesHandling")
    def muting_rules_handling(self) -> pulumi.Output[_builtins.str]:
        """
        How to handle muted issues. See Muting Rules below for details.
        """
        return pulumi.get(self, "muting_rules_handling")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the workflow.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="workflowId")
    def workflow_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the workflow.
        """
        return pulumi.get(self, "workflow_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAuthenticationDomainResult',
    'AwaitableGetAuthenticationDomainResult',
    'get_authentication_domain',
    'get_authentication_domain_output',
]

@pulumi.output_type
class GetAuthenticationDomainResult:
    """
    A collection of values returned by getAuthenticationDomain.
    """
    def __init__(__self__, id=None, name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the matching authentication domain fetched.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")


class AwaitableGetAuthenticationDomainResult(GetAuthenticationDomainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthenticationDomainResult(
            id=self.id,
            name=self.name)


def get_authentication_domain(name: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthenticationDomainResult:
    """
    Use this data source to fetch the ID of an authentication domain belonging to your account, matching the specified name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    pulumi.export("foo", foo.id)
    ```


    :param _builtins.str name: The name of the authentication domain to be searched for. An error is thrown, if no authentication domain is found with the specified name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getAuthenticationDomain:getAuthenticationDomain', __args__, opts=opts, typ=GetAuthenticationDomainResult).value

    return AwaitableGetAuthenticationDomainResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'))
def get_authentication_domain_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAuthenticationDomainResult]:
    """
    Use this data source to fetch the ID of an authentication domain belonging to your account, matching the specified name.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.get_authentication_domain(name="Test Authentication Domain")
    pulumi.export("foo", foo.id)
    ```


    :param _builtins.str name: The name of the authentication domain to be searched for. An error is thrown, if no authentication domain is found with the specified name.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getAuthenticationDomain:getAuthenticationDomain', __args__, opts=opts, typ=GetAuthenticationDomainResult)
    return __ret__.apply(lambda __response__: GetAuthenticationDomainResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GcpLinkAccountArgs', 'GcpLinkAccount']

@pulumi.input_type
class GcpLinkAccountArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GcpLinkAccount resource.
        :param pulumi.Input[_builtins.str] project_id: Project ID of the GCP account.
        :param pulumi.Input[_builtins.str] account_id: Account ID of the New Relic account.
        :param pulumi.Input[_builtins.str] name: name of the linked account
        """
        pulumi.set(__self__, "project_id", project_id)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        Project ID of the GCP account.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account ID of the New Relic account.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the linked account
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _GcpLinkAccountState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GcpLinkAccount resources.
        :param pulumi.Input[_builtins.str] account_id: Account ID of the New Relic account.
        :param pulumi.Input[_builtins.str] name: name of the linked account
        :param pulumi.Input[_builtins.str] project_id: Project ID of the GCP account.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account ID of the New Relic account.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        name of the linked account
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Project ID of the GCP account.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.type_token("newrelic:cloud/gcpLinkAccount:GcpLinkAccount")
class GcpLinkAccount(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to link a GCP account to New Relic.

        ## Prerequisite

        To start receiving Google Cloud Platform (GCP) data with New Relic GCP integrations, connect your Google project to New Relic infrastructure monitoring. If you don't have one already, create a New Relic account. It's free, forever.

        Setup is required in GCP for this resource to work properly. The New Relic GCP integration can be done by creating a user account or a service account.

        A user with Project IAM Admin role is needed to add the service account ID as a member in your GCP project.

        In the GCP project IAM & admin, the service account must have the Project Viewer role and the Service Usage Consumer role or, alternatively, a custom role.

        Follow the [steps outlined here](https://docs.newrelic.com/docs/infrastructure/google-cloud-platform-integrations/get-started/connect-google-cloud-platform-services-new-relic) to set up the integration.

        ## Example Usage

        You can also use the full example, including the GCP set up, found in our guides.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.cloud.GcpLinkAccount("foo",
            account_id="account id of newrelic account",
            project_id="id of the Project",
            name="account name")
        ```

        ## Import

        Linked GCP accounts can be imported using `id`, you can find the `id` of an existing GCP linked accounts in GCP dashboard under Infrastructure in Newrelic Console.

        bash

        ```sh
        $ pulumi import newrelic:cloud/gcpLinkAccount:GcpLinkAccount  newrelic_cloud_gcp_link_account.foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account ID of the New Relic account.
        :param pulumi.Input[_builtins.str] name: name of the linked account
        :param pulumi.Input[_builtins.str] project_id: Project ID of the GCP account.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GcpLinkAccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to link a GCP account to New Relic.

        ## Prerequisite

        To start receiving Google Cloud Platform (GCP) data with New Relic GCP integrations, connect your Google project to New Relic infrastructure monitoring. If you don't have one already, create a New Relic account. It's free, forever.

        Setup is required in GCP for this resource to work properly. The New Relic GCP integration can be done by creating a user account or a service account.

        A user with Project IAM Admin role is needed to add the service account ID as a member in your GCP project.

        In the GCP project IAM & admin, the service account must have the Project Viewer role and the Service Usage Consumer role or, alternatively, a custom role.

        Follow the [steps outlined here](https://docs.newrelic.com/docs/infrastructure/google-cloud-platform-integrations/get-started/connect-google-cloud-platform-services-new-relic) to set up the integration.

        ## Example Usage

        You can also use the full example, including the GCP set up, found in our guides.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.cloud.GcpLinkAccount("foo",
            account_id="account id of newrelic account",
            project_id="id of the Project",
            name="account name")
        ```

        ## Import

        Linked GCP accounts can be imported using `id`, you can find the `id` of an existing GCP linked accounts in GCP dashboard under Infrastructure in Newrelic Console.

        bash

        ```sh
        $ pulumi import newrelic:cloud/gcpLinkAccount:GcpLinkAccount  newrelic_cloud_gcp_link_account.foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param GcpLinkAccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GcpLinkAccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GcpLinkAccountArgs.__new__(GcpLinkAccountArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
        super(GcpLinkAccount, __self__).__init__(
            'newrelic:cloud/gcpLinkAccount:GcpLinkAccount',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'GcpLinkAccount':
        """
        Get an existing GcpLinkAccount resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account ID of the New Relic account.
        :param pulumi.Input[_builtins.str] name: name of the linked account
        :param pulumi.Input[_builtins.str] project_id: Project ID of the GCP account.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GcpLinkAccountState.__new__(_GcpLinkAccountState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        return GcpLinkAccount(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account ID of the New Relic account.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        name of the linked account
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        Project ID of the GCP account.
        """
        return pulumi.get(self, "project_id")

